@@ -2,7 +2,7 @@
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
     Copyright (C) 2007-2012 Piotr Eljasiak
-    Copyright (C) 2013 Uwe Scholz
+    Copyright (C) 2013-2014 Uwe Scholz
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -653,7 +653,7 @@ create_error_dialog (const gchar *msg, ...)
     va_end (argptr);
 
     dialog = gtk_message_dialog_new (GTK_WINDOW (main_win_widget), GTK_DIALOG_MODAL,
-                                     GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, string);
+                                     GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "%s", string);
 
     gtk_signal_connect (GTK_OBJECT (dialog), "response", GTK_SIGNAL_FUNC (on_response), dialog);
 
@@ -674,7 +674,7 @@ create_warning_dialog (const gchar *msg, ...)
 
     dialog = gtk_message_dialog_new (
         GTK_WINDOW (main_win_widget), GTK_DIALOG_MODAL,
-        GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, msg);
+        GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, "%s", msg);
 
     gtk_signal_connect (GTK_OBJECT (dialog), "response",
                         GTK_SIGNAL_FUNC (on_response), dialog);
