@@ -2,7 +2,7 @@
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
     Copyright (C) 2007-2012 Piotr Eljasiak
-    Copyright (C) 2013 Uwe Scholz
+    Copyright (C) 2013-2014 Uwe Scholz
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #define NAME "Example"
 #define COPYRIGHT "Copyright \xc2\xa9 2003-2006 Marcus Bjurman"
 #define AUTHOR "Marcus Bjurman <marbj499@student.liu.se>"
-#define WEBPAGE "http://www.nongnu.org/gcmd"
+#define WEBPAGE "http://gcmd.github.io"
 
 
 static PluginInfo plugin_nfo = {
