@@ -2,7 +2,7 @@
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
     Copyright (C) 2007-2012 Piotr Eljasiak
-    Copyright (C) 2013 Uwe Scholz
+    Copyright (C) 2013-2014 Uwe Scholz
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -1556,10 +1556,10 @@ void help_web (GtkMenuItem *menuitem, gpointer not_used)
     GError *error = NULL;
 
 #if GTK_CHECK_VERSION (2, 14, 0)
-    if (!gtk_show_uri (NULL, "http://www.nongnu.org/gcmd/", GDK_CURRENT_TIME, &error))
+    if (!gtk_show_uri (NULL, "http://gcmd.github.io/", GDK_CURRENT_TIME, &error))
         gnome_cmd_error_message (_("There was an error opening home page."), error);
 #else
-    if (!gnome_url_show ("http://www.nongnu.org/gcmd/", &error))
+    if (!gnome_url_show ("http://gcmd.github.io/", &error))
         gnome_cmd_error_message (_("There was an error opening home page."), error);
 #endif
 }
@@ -1585,17 +1585,20 @@ void help_about (GtkMenuItem *menuitem, gpointer not_used)
         "Marcus Bjurman <marbj499@student.liu.se>",
         "Piotr Eljasiak <epiotr@use.pl>",
         "Assaf Gordon <agordon88@gmail.com>",
+        "Uwe Scholz <u.scholz83@gmx.de>",
         NULL
     };
 
     static const gchar *documenters[] = {
         "Marcus Bjurman <marbj499@student.liu.se>",
         "Piotr Eljasiak <epiotr@use.pl>",
+        "Uwe Scholz <u.scholz83@gmx.de>",
         NULL
     };
 
     static const gchar copyright[] = "Copyright \xc2\xa9 2001-2006 Marcus Bjurman\n"
-                                     "Copyright \xc2\xa9 2007-2012 Piotr Eljasiak";
+                                     "Copyright \xc2\xa9 2007-2012 Piotr Eljasiak\n"
+                                     "Copyright \xc2\xa9 2013-2014 Uwe Scholz";
 
     static const gchar comments[] = N_("A fast and powerful file manager for the GNOME desktop");
 
@@ -1627,7 +1630,7 @@ void help_about (GtkMenuItem *menuitem, gpointer not_used)
                            "documenters", documenters,
                            "logo-icon-name", PACKAGE_NAME,
                            "translator-credits", _("translator-credits"),
-                           "website", "http://www.nongnu.org/gcmd",
+                           "website", "http://gcmd.github.io",
                            "website-label", "GNOME Commander Website",
                            NULL);
 
