@@ -2,7 +2,7 @@
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
     Copyright (C) 2007-2012 Piotr Eljasiak
-    Copyright (C) 2013 Uwe Scholz
+    Copyright (C) 2013-2014 Uwe Scholz
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -603,7 +603,7 @@ void gnome_cmd_xml_config_save (const gchar *path, GnomeCmdData &cfg)
         return;
 
     fputs("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n", f);
-    fputs("<!-- Created with GNOME Commander (http://www.nongnu.org/gcmd/) -->\n", f);
+    fputs("<!-- Created with GNOME Commander (http://gcmd.github.io/) -->\n", f);
     fputs("<GnomeCommander version=\"" VERSION "\">\n", f);
     fputs("\t<AdvancedRenameTool>\n", f);
     fprintf (f, "\t\t<WindowSize width=\"%i\" height=\"%i\" />\n", cfg.advrename_defaults.width, cfg.advrename_defaults.height);
